env

package
v0.0.0-...-424504c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2015 License: BSD-2-Clause Imports: 9 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

var (
	Booting = make(chan bool)

	// Debug is set via the -debug flag for the serve command.
	Debug bool
	// Handler comes from calling Handler() on a gadget.App object. It's used by the serve command to run the server.
	Handler http.HandlerFunc
)

Functions

func Get

func Get(varname string) string

func Log

func Log(v ...interface{})

Log writes arguments v as a single line to the default logger.

func Open

func Open(path string) (*os.File, error)

Open wraps os.Open, but with the assumption that the path is relative to the project root.

func RelPath

func RelPath(path ...string) string

RelPath creates an absolute path from path segments path relative to the project root.

Types

type Serve

type Serve struct {
	*quimby.Flagger
}

The Serve command makes it easy to run Gadget applications.

func (*Serve) Desc

func (s *Serve) Desc() string

func (*Serve) Run

func (s *Serve) Run()

Run sets up a logger and runs the Handler.

func (*Serve) SetFlags

func (s *Serve) SetFlags()

SetFlags defines flags for the serve command.

Jump to